// Generated by gir (https://github.com/gtk-rs/gir @ c93f8f31b6a5)
// from  (@ 3879ff8e0201+)
// from gir-files (@ 01ea5f1a07cd)
// DO NOT EDIT

fn main() {
    if std::env::var("DOCS_RS").is_ok() {
        // prevent linking libraries to avoid documentation failure
        return;
    }

    if let Err(s) = system_deps::Config::new().probe() {
        println!("cargo:warning={s}");
        std::process::exit(1);
    }
}
