// Generated by gir (https://github.com/gtk-rs/gir @ c93f8f31b6a5)
// from  (@ 3879ff8e0201+)
// from gir-files (@ 01ea5f1a07cd)
// DO NOT EDIT

#![allow(non_camel_case_types, non_upper_case_globals, non_snake_case)]
#![allow(
    clippy::approx_constant,
    clippy::type_complexity,
    clippy::unreadable_literal,
    clippy::upper_case_acronyms
)]
#![cfg_attr(docsrs, feature(doc_cfg))]

#[allow(unused_imports)]
use std::ffi::{
    c_char, c_double, c_float, c_int, c_long, c_short, c_uchar, c_uint, c_ulong, c_ushort, c_void,
};

#[allow(unused_imports)]
use glib::{GType, gboolean, gconstpointer, gpointer};
#[allow(unused_imports)]
use libc::{FILE, intptr_t, off_t, size_t, ssize_t, time_t, uintptr_t};
#[cfg(unix)]
#[allow(unused_imports)]
use libc::{dev_t, gid_t, pid_t, socklen_t, uid_t};
use {gdk_sys as gdk, glib_sys as glib, gly_sys as gly};

unsafe extern "C" {

    //=========================================================================
    // Other functions
    //=========================================================================
    pub fn gly_gtk_frame_get_texture(frame: *mut gly::GlyFrame) -> *mut gdk::GdkTexture;

}
